[ARVADOS] updated: 1.3.0-1851-g73eb047a9

Git user git at public.curoverse.com
Thu Nov 14 21:32:35 UTC 2019


Summary of changes:
 build/run-library.sh | 1 +
 build/run-tests.sh   | 7 ++++---
 2 files changed, 5 insertions(+), 3 deletions(-)

       via  73eb047a9a1eb83d10c84cc959fdd049b7fd5fab (commit)
      from  3b9af4b0f7eb42115f57189f657b12a0ae2e3a8c (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.


commit 73eb047a9a1eb83d10c84cc959fdd049b7fd5fab
Author: Tom Clegg <tclegg at veritasgenetics.com>
Date:   Thu Nov 14 16:31:56 2019 -0500

    15107: Update "go get" uses in test/package scripts.
    
    Arvados-DCO-1.1-Signed-off-by: Tom Clegg <tclegg at veritasgenetics.com>

diff --git a/build/run-library.sh b/build/run-library.sh
index cc491770c..a4cebbc8a 100755
--- a/build/run-library.sh
+++ b/build/run-library.sh
@@ -111,6 +111,7 @@ calculate_go_package_version() {
   local src_path="$1"; shift
 
   cd "$WORKSPACE/$src_path"
+  go mod download
   local version="$(version_from_git)"
   local timestamp="$(timestamp_from_git)"
 
diff --git a/build/run-tests.sh b/build/run-tests.sh
index 8cf61b9ed..38005070c 100755
--- a/build/run-tests.sh
+++ b/build/run-tests.sh
@@ -631,6 +631,7 @@ initialize() {
 }
 
 install_env() {
+    go mod download || fatal "Go deps failed"
     which goimports >/dev/null || go get golang.org/x/tools/cmd/goimports || fatal "Go setup failed"
 
     setup_virtualenv "$VENVDIR" --python python2.7
@@ -752,11 +753,11 @@ do_test_once() {
     then
         covername="coverage-$(echo "$1" | sed -e 's/\//_/g')"
         coverflags=("-covermode=count" "-coverprofile=$WORKSPACE/tmp/.$covername.tmp")
         # We do "go get -t" here to catch compilation errors
         # before trying "go test". Otherwise, coverage-reporting
         # mode makes Go show the wrong line numbers when reporting
         # compilation errors.
-        go get -ldflags "$(go_ldflags)" -t "git.curoverse.com/arvados.git/$1" && \
+        go install -ldflags "$(go_ldflags)" "$WORKSPACE/$1" && \
             cd "$WORKSPACE/$1" && \
             if [[ -n "${testargs[$1]}" ]]
         then
@@ -844,7 +845,7 @@ do_install_once() {
         result=1
     elif [[ "$2" == "go" ]]
     then
-        go get -ldflags "$(go_ldflags)" -t "git.curoverse.com/arvados.git/$1"
+        go install -ldflags "$(go_ldflags)" "$WORKSPACE/$1"
     elif [[ "$2" == "pip" ]]
     then
         # $3 can name a path directory for us to use, including trailing

-----------------------------------------------------------------------
@@ -752,11 +753,11 @@ do_test_once() {
         covername="coverage-$(echo "$1" | sed -e 's/\//_/g')"
         coverflags=("-covermode=count" "-coverprofile=$WORKSPACE/tmp/.$covername.tmp")
-        # We do "go get -t" here to catch compilation errors
+        # We do "go install" here to catch compilation errors
         # before trying "go test". Otherwise, coverage-reporting
         # mode makes Go show the wrong line numbers when reporting


hooks/post-receive
-- 




More information about the arvados-commits mailing list